# ty

ty is an extremely fast type checker.
Currently, it is a work-in-progress and not ready for production use.

The Rust code for ty lives in this repository; see [CONTRIBUTING.md](CONTRIBUTING.md) for more
information on contributing to ty.

See [the ty repo](https://github.com/astral-sh/ty) for ty documentation and releases.
